@@ -548,6 +548,15 @@ class ItemGroupData(OE.ODMElement):
     Annotation = T.ODMListObject(required=False, element_class=Annotation)
     ItemData = T.ODMListObject(required=False, element_class=ItemData)
 
+    def __len__(self):
+        return len(self.ItemData)
+
+    def __getitem__(self, position):
+        return self.ItemData[position]
+
+    def __iter__(self):
+        return iter(self.ItemData)
+
 
 class FormData(OE.ODMElement):
     FormOID = T.OIDRef(required=True)
@@ -559,6 +568,15 @@ class FormData(OE.ODMElement):
     Annotation = T.ODMListObject(required=False, element_class=Annotation)
     ItemGroupData = T.ODMListObject(required=False, element_class=ItemGroupData)
 
+    def __len__(self):
+        return len(self.ItemGroupData)
+
+    def __getitem__(self, position):
+        return self.ItemGroupData[position]
+
+    def __iter__(self):
+        return iter(self.ItemGroupData)
+
 
 class StudyEventData(OE.ODMElement):
     StudyEventOID = T.OIDRef(required=True)
@@ -569,6 +587,15 @@ class StudyEventData(OE.ODMElement):
     Annotation = T.ODMListObject(required=False, element_class=Annotation)
     FormData = T.ODMListObject(required=False, element_class=FormData)
 
+    def __len__(self):
+        return len(self.FormData)
+
+    def __getitem__(self, position):
+        return self.FormData[position]
+
+    def __iter__(self):
+        return iter(self.FormData)
+
 
 class SubjectData(OE.ODMElement):
     SubjectKey = T.String(required=True)
@@ -580,6 +607,15 @@ class SubjectData(OE.ODMElement):
     Annotation = T.ODMListObject(required=False, element_class=Annotation)
     StudyEventData = T.ODMListObject(required=False, element_class=StudyEventData)
 
+    def __len__(self):
+        return len(self.StudyEventData)
+
+    def __getitem__(self, position):
+        return self.StudyEventData[position]
+
+    def __iter__(self):
+        return iter(self.StudyEventData)
+
 
 class AuditRecords(OE.ODMElement):
     AuditRecord = T.ODMListObject(required=False, element_class=AuditRecord)
@@ -601,6 +637,15 @@ class ClinicalData(OE.ODMElement):
     Signatures = T.ODMListObject(element_class=Signatures)
     Annotations = T.ODMListObject(element_class=Annotations)
 
+    def __len__(self):
+        return len(self.SubjectData)
+
+    def __getitem__(self, position):
+        return self.SubjectData[position]
+
+    def __iter__(self):
+        return iter(self.SubjectData)
+
 
 class ReferenceData(OE.ODMElement):
     StudyOID = T.OIDRef(required=True)
