@@ -6,7 +6,6 @@ class ValueSet:
                                "SUBJECT LEVEL ANALYSIS DATASET", "BASIC DATA STRUCTURE", "ADAM OTHER"],
         "PDFPageRef.Type": ["NamedDestination", "PhysicalRef"],
         "Origin.Type": ["CRF", "Derived", "Assigned", "Protocol", "eDT", "Predecessor"],
-        "Origin.Source": ["Collected", "Derived", "Assigned", "Protocol", "Predecessor", "Not Available"],
         "RangeCheck.Comparator": ["LT", "LE", "GT", "GE", "EQ", "NE", "IN", "NOTIN"],
         "RangeCheck.SoftHard": ["Soft", "Hard"],
         "StudyEventDef.Repeating": ["Yes", "No"],
@@ -29,6 +28,7 @@ class ValueSet:
                              "incompleteDate", "incompleteTime", "URI"],
         "CodeList.DataType": ["integer", "float", "text", "string"],
         "CodeList.IsNonStandard": ["Yes"],
+        "CodeList.CodeListExtensible": ["Yes", "No"],
         "MethodDef.Type": ["Computation", "Imputation", "Transpose", "Other"],
         "StudyEventDef.Type": ["Scheduled", "Unscheduled", "Common"],
         "ODM.FileType": ["Snapshot", "Transactional"],
